@@ -495,44 +495,6 @@ bool RPackageLister::distUpgrade()
    return true;
 }
 
-
-
-
-void RPackageLister::reapplyFilter()
-{
-   // PORTME
-   if (_updating)
-      return;
-
-   _viewPackages.clear();
-   _viewPackagesIndex.clear();
-   _viewPackagesIndex.resize(_packagesIndex.size(), -1);
-
-   for (RPackageView::iterator I = _selectedView->begin();
-        I != _selectedView->end(); I++) {
-      if (*I) {
-         _viewPackagesIndex[(*(*I)->package())->ID] = _viewPackages.size();
-         _viewPackages.push_back(*I);
-      }
-   }
-
-   // sort now according to the latest used sort method
-   switch (_sortMode) {
-
-      case LIST_SORT_NAME:
-         sortPackagesByName();
-         break;
-
-      case LIST_SORT_SIZE_ASC:
-         sortPackagesByInstSize(0);
-         break;
-
-      case LIST_SORT_SIZE_DES:
-         sortPackagesByInstSize(1);
-         break;
-   }
-}
-
 static void qsSortByName(vector<RPackage *> &packages, int start, int end)
 {
    int i, j;
@@ -563,11 +525,94 @@ static void qsSortByName(vector<RPackage *> &packages, int start, int end)
 
 void RPackageLister::sortPackagesByName(vector<RPackage *> &packages)
 {
+   //   cout << "RPackageLister::sortPackagesByName()" << endl;
    _sortMode = LIST_SORT_NAME;
    if (!packages.empty())
       qsSortByName(packages, 0, packages.size() - 1);
 }
 
+
+void RPackageLister::reapplyFilter()
+{
+   // PORTME
+   if (_updating)
+      return;
+
+   //   cout << "RPackageLister::reapplyFilter()" << endl;
+
+   _viewPackages.clear();
+   _viewPackagesIndex.clear();
+   _viewPackagesIndex.resize(_packagesIndex.size(), -1);
+
+   for (RPackageView::iterator I = _selectedView->begin();
+        I != _selectedView->end(); I++) {
+      if (*I) {
+         _viewPackagesIndex[(*(*I)->package())->ID] = _viewPackages.size();
+         _viewPackages.push_back(*I);
+      }
+   }
+
+   // sort now according to the latest used sort method
+   switch (_sortMode) {
+      case LIST_SORT_STATUS_ASC:
+	 // make sure that we sort for names first, otherwise we get a funny list
+         sortPackagesByName();
+         sortPackagesByStatus(0);
+         break;
+      case LIST_SORT_STATUS_DES:
+	 // make sure that we sort for names first, otherwise we get a funny list
+         sortPackagesByName();
+         sortPackagesByStatus(1);
+         break;
+
+      case LIST_SORT_NAME:
+         sortPackagesByName();
+         break;
+
+      case LIST_SORT_SIZE_ASC:
+         sortPackagesByInstSize(0);
+         break;
+
+      case LIST_SORT_SIZE_DES:
+         sortPackagesByInstSize(1);
+         break;
+   }
+}
+
+
+static const int status_sort_magic = (  RPackage::FInstalled 
+				      | RPackage::FOutdated 
+				      | RPackage::FNew);
+struct statusSortFuncAsc {
+   bool operator() (RPackage *x, RPackage *y) {
+      return (x->getFlags() & (status_sort_magic))  > 
+	     (y->getFlags() & (status_sort_magic));
+}};
+struct statusSortFuncDes {
+   bool operator() (RPackage *x, RPackage *y) {
+      return (x->getFlags() & (status_sort_magic))  < 
+	     (y->getFlags() & (status_sort_magic));
+}};
+
+void RPackageLister::sortPackagesByStatus(vector<RPackage *> &packages, 
+					  int order)
+{
+//    cout << "RPackageLister::sortPackagesByStatus() " 
+// 	<< "size: " << packages.size() << endl;
+
+   if (order == 0)
+      _sortMode = LIST_SORT_STATUS_ASC;
+   else
+      _sortMode = LIST_SORT_STATUS_DES;
+
+   if (!packages.empty())
+      if(order==0)
+	 stable_sort(packages.begin(), packages.end(), statusSortFuncAsc());
+      else
+	 stable_sort(packages.begin(), packages.end(), statusSortFuncDes());
+}
+
+
 struct instSizeSortFuncAsc {
    bool operator() (RPackage *x, RPackage *y) {
       return x->installedSize() < y->installedSize();
@@ -589,12 +634,13 @@ void RPackageLister::sortPackagesByInstSize(vector<RPackage *> &packages,
 
    if (!packages.empty()) {
       if (order == 0)
-         sort(packages.begin(), packages.end(), instSizeSortFuncAsc());
+         stable_sort(packages.begin(), packages.end(), instSizeSortFuncAsc());
       else
-         sort(packages.begin(), packages.end(), instSizeSortFuncDes());
+         stable_sort(packages.begin(), packages.end(), instSizeSortFuncDes());
    }
 }
 
+
 int RPackageLister::findPackage(const char *pattern)
 {
    if (_searchData.isRegex)
