@@ -32,59 +32,57 @@
 
 #include "i18n.h"
 
-class RPackageLister;
+class RPackageViewFilter;
 class RGFilterManagerWindow;
 
 // must be in the same order as of the check buttons
-static const RStatusPackageFilter::Types StatusMasks[] =  {
-    RStatusPackageFilter::NotInstalled,
-    RStatusPackageFilter::Upgradable,
-    RStatusPackageFilter::Installed,
-    RStatusPackageFilter::MarkKeep,
-    RStatusPackageFilter::MarkInstall,
-    RStatusPackageFilter::MarkRemove,
-    RStatusPackageFilter::Broken,
-    RStatusPackageFilter::NewPackage,
-    RStatusPackageFilter::PinnedPackage,
-    RStatusPackageFilter::OrphanedPackage, // debian only (for now)
-    RStatusPackageFilter::ResidualConfig,
-    RStatusPackageFilter::NotInstallable
-
+static const RStatusPackageFilter::Types StatusMasks[] = {
+   RStatusPackageFilter::NotInstalled,
+   RStatusPackageFilter::Upgradable,
+   RStatusPackageFilter::Installed,
+   RStatusPackageFilter::MarkKeep,
+   RStatusPackageFilter::MarkInstall,
+   RStatusPackageFilter::MarkRemove,
+   RStatusPackageFilter::Broken,
+   RStatusPackageFilter::NewPackage,
+   RStatusPackageFilter::PinnedPackage,
+   RStatusPackageFilter::OrphanedPackage,       // debian only
+   RStatusPackageFilter::ResidualConfig,        // debian only
+   RStatusPackageFilter::NotInstallable,
+   RStatusPackageFilter::UpstreamUpgradable
 };
-// FIXME: if you add a new status change this const! (calc automaticlly)
-#ifndef HAVE_RPM
-static const int NrOfStatusBits = 12;
-#else
-static const int NrOfStatusBits = 10;
-#endif
 
-static char  *ActOptions[] = {
-    _("Includes"),
-    _("Excludes"),
-    NULL
+// FIXME: if you add a new status change this const! (calc automaticlly)
+static const int NrOfStatusBits = 13;
+
+static char *ActOptions[] = {
+   _("Includes"),
+   _("Excludes"),
+   NULL
 };
 
 
 static char *DepOptions[] = {
-    _("Package name"),
-    _("Version number"),
-    _("Description"),
-    _("Maintainer"),
-    _("Dependencies"), // depends, predepends etc
-    _("Provided packages"), // provides and name
-    _("Conflicting packages"), // conflicts
-    _("Replaced packages"), // replaces/obsoletes
-    _("Suggestions or recommendations"), // suggests/recommends
-    _("Reverse dependencies"), // Reverse Depends
-    NULL
+   _("Package name"),
+   _("Version number"),
+   _("Description"),
+   _("Maintainer"),
+   _("Dependencies"),           // depends, predepends etc
+   _("Provided packages"),      // provides and name
+   _("Conflicting packages"),   // conflicts
+   _("Replaced packages"),      // replaces/obsoletes
+   _("Recommendations"), ///recommends
+   _("Suggestions"),   // suggests
+   _("Dependants"),   // Reverse Depends
+   _("Origin"),                 // Origin (e.g. security.debian.org)
+   NULL
 };
 
 
 
 typedef void RGFilterEditorCloseAction(void *self, bool okcancel);
 
-class RGFilterManagerWindow : public RGGladeWindow 
-{
+class RGFilterManagerWindow:public RGGladeWindow {
    static void addFilterAction(GtkWidget *self, void *data);
    static void removeFilterAction(GtkWidget *self, void *data);
 
@@ -96,8 +94,8 @@ class RGFilterManagerWindow : public RGGladeWindow
    static void includeTagAction(GtkWidget *self, void *data);
    static void excludeTagAction(GtkWidget *self, void *data);
 
-   static gint deleteEventAction(GtkWidget *widget, GdkEvent  *event,
-				 gpointer   data );
+   static gint deleteEventAction(GtkWidget *widget, GdkEvent * event,
+                                 gpointer data);
 
    static void selectAction(GtkTreeSelection *selection, gpointer data);
 
@@ -107,51 +105,44 @@ class RGFilterManagerWindow : public RGGladeWindow
    void editFilter();
 
    // helpers
-   void setSectionFilter(RSectionPackageFilter &f);
-   void getSectionFilter(RSectionPackageFilter &f);
-   
-   void setStatusFilter(RStatusPackageFilter &f);
-   void getStatusFilter(RStatusPackageFilter &f);
-   
+   void setSectionFilter(RSectionPackageFilter & f);
+   void getSectionFilter(RSectionPackageFilter & f);
+
+   void setStatusFilter(RStatusPackageFilter & f);
+   void getStatusFilter(RStatusPackageFilter & f);
+
    void setPatternFilter(RPatternPackageFilter &f);
    void getPatternFilter(RPatternPackageFilter &f);
 
-#ifdef HAVE_DEBTAGS
-   void setTagFilter(RTagPackageFilter &f);
-   void getTagFilter(RTagPackageFilter &f);
-#endif
-   void setFilterView(RFilter *f);
-   void getFilterView(RFilter *f);
-
-   GtkTreePath* treeview_find_path_from_text(GtkTreeModel *model, char *text);
+   GtkTreePath *treeview_find_path_from_text(GtkTreeModel *model, char *text);
 
    // close callbacks
    RGFilterEditorCloseAction *_closeAction;
    void *_closeData;
-   bool _okcancel;            // did the user click ok or cancel
+   bool _okcancel;              // did the user click ok or cancel
 
-   GtkWidget *_filterEntry;  /* GtkEntry */
+   GtkWidget *_filterEntry;     /* GtkEntry */
    GdkCursor *_busyCursor;
 
-   GtkWidget *_filterDetailsBox; // detail box
+   GtkWidget *_filterDetailsBox;        // detail box
 
    // the filter list
-   GtkWidget *_filterList;   /* GtkTreeView */
+   GtkWidget *_filterList;      /* GtkTreeView */
    GtkListStore *_filterListStore;
    GtkTreePath *_selectedPath;
    RFilter *_selectedFilter;
    enum {
-       NAME_COLUMN,
-       FILTER_COLUMN,
-       N_COLUMNS
+      NAME_COLUMN,
+      FILTER_COLUMN,
+      N_COLUMNS
    };
 
    // the section list
-   GtkWidget *_sectionList;   /* GtkTreeView */
+   GtkWidget *_sectionList;     /* GtkTreeView */
    GtkListStore *_sectionListStore;
    enum {
-       SECTION_COLUMN,
-       SECTION_N_COLUMNS
+      SECTION_COLUMN,
+      SECTION_N_COLUMNS
    };
 
    // status filter buttons
@@ -159,17 +150,17 @@ class RGFilterManagerWindow : public RGGladeWindow
 
    // the pattern list
    enum {
-       PATTERN_DO_COLUMN,
-       PATTERN_WHAT_COLUMN,
-       PATTERN_TEXT_COLUMN,       
-       PATTERN_N_COLUMNS
+      PATTERN_DO_COLUMN,
+      PATTERN_WHAT_COLUMN,
+      PATTERN_TEXT_COLUMN,
+      PATTERN_N_COLUMNS
    };
-   GtkWidget *_patternList;   /* GtkTreeView */
+   GtkWidget *_patternList;     /* GtkTreeView */
    GtkListStore *_patternListStore;
    bool setPatternRow(int row, bool exclude,
-		      RPatternPackageFilter::DepType type, string pattern);
+                      RPatternPackageFilter::DepType type, string pattern);
    static void patternSelectionChanged(GtkTreeSelection *selection,
-				       gpointer data);
+                                       gpointer data);
    static void patternChanged(GObject *o, gpointer data);
    static void patternNew(GObject *o, gpointer data);
    static void patternDelete(GObject *o, gpointer data);
@@ -183,41 +174,40 @@ class RGFilterManagerWindow : public RGGladeWindow
    // the view menu
    GtkWidget *_optionmenu_view_mode;
    GtkWidget *_optionmenu_expand_mode;
-   
+
    // the lister is always needed
-   RPackageLister *_lister;  
-   vector<RFilter*> _saveFilters;
+   RPackageViewFilter *_filterview;
+   vector<RFilter *> _saveFilters;
 
 #ifdef HAVE_DEBTAGS
    // the tags stuff
    GtkTreeView *_availableTagsView;
    GtkListStore *_availableTagsList;
-   
+
    GtkTreeView *_includedTagsView;
    GtkListStore *_includedTagsList;
 
    GtkTreeView *_excludedTagsView;
    GtkListStore *_excludedTagsList;
-   
+
    static void treeViewExcludeClicked(GtkTreeView *treeview,
-				      GtkTreePath *arg1,
-				      GtkTreeViewColumn *arg2,
-				      gpointer user_data);
+                                      GtkTreePath *arg1,
+                                      GtkTreeViewColumn *arg2,
+                                      gpointer user_data);
    static void treeViewIncludeClicked(GtkTreeView *treeview,
-				      GtkTreePath *arg1,
-				      GtkTreeViewColumn *arg2,
-				      gpointer user_data);
+                                      GtkTreePath *arg1,
+                                      GtkTreeViewColumn *arg2,
+                                      gpointer user_data);
 #endif
 
-public:
-   RGFilterManagerWindow(RGWindow *win, RPackageLister *lister);
+ public:
+   RGFilterManagerWindow(RGWindow *win, RPackageViewFilter *filterview);
 
    void setCloseCallback(RGFilterEditorCloseAction *action, void *data);
    virtual bool close();
    virtual void show();
-  
+
 };
 
 
 #endif
-
